@@ -1,18 +1,18 @@
-/* This file is part of Rush.                  
+/* This file is part of GNU Rush.                  
    Copyright (C) 2008, 2009 Sergey Poznyakoff
 
-   Rush is free software; you can redistribute it and/or modify
+   GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
-   Rush is distributed in the hope that it will be useful,
+   GNU Rush is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Rush.  If not, see <http://www.gnu.org/licenses/>. */
+   along with GNU Rush.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <rush.h>
 
@@ -26,8 +26,6 @@ int debug_option;
 struct rush_rule *rule_head, *rule_tail;
 struct passwd *rush_pw;
 
-static char *progname;
-
 #define STDOUT_FILENO 1
 #define STDERR_FILENO 2
 
@@ -60,7 +58,7 @@ void
 vlogmsg(int prio, const char *fmt, va_list ap)
 {
 	if (lint_option) {
-		fprintf(stderr, "%s: ", progname);
+		fprintf(stderr, "%s: ", program_name);
 		switch (prio) {
 		case LOG_DEBUG:
 			fprintf(stderr, _("Debug: "));
@@ -739,16 +737,11 @@ main(int argc, char **argv)
         struct rush_rule *rule;
         struct rush_request req;
 
-
+	rush_set_program_name(argv[0]);
 	rush_i18n_init();
-        progname = strrchr(argv[0], '/');
-        if (progname)
-                progname++;
-        else
-                progname = argv[0];
         umask(~(mode_t)0);
         
-        openlog(progname, LOG_NDELAY|LOG_PID, LOG_AUTHPRIV);
+        openlog(program_name, LOG_NDELAY|LOG_PID, LOG_AUTHPRIV);
 
 	get_options(argc, argv);
 
