@@ -1,24 +1,22 @@
-/* This file is part of Rush.                  
+/* This file is part of GNU Rush.                  
    Copyright (C) 2008, 2009 Sergey Poznyakoff
 
-   Rush is free software; you can redistribute it and/or modify
+   GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
-   Rush is distributed in the hope that it will be useful,
+   GNU Rush is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Rush.  If not, see <http://www.gnu.org/licenses/>. */
+   along with GNU Rush.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <rush.h>
 #include "error.h"
 
-char *program_name;
-
 char *base_name = RUSH_DB;
 int  display_header = 1;  /* Display header line */
 int forward = 0;
@@ -63,12 +61,8 @@ main(int argc, char **argv)
         rushdb_format_t form;
         unsigned long i;
         
+	rush_set_program_name(argv[0]);
         rush_i18n_init();
-        program_name = strrchr(argv[0], '/');
-        if (program_name)
-                program_name++;
-        else
-                program_name = argv[0];
 
         format = getenv("RUSHLAST_FORMAT");
         if (!format)
